# yahoo_fantasy_ai
python bindings to the Yahoo! Fantasy API

## Build status

[![Build Status](https://travis-ci.com/spilchen/yahoo_fantasy_api.svg?branch=master)](https://travis-ci.com/spilchen/yahoo_fantasy_api)
